.. nme documentation master file, created by
   sphinx-quickstart on Fri Apr  1 00:32:04 2022.
   You can adapt this file completely to your liking, but it should at least
   contain the root ``toctree`` directive.

Welcome to nme's documentation!
===============================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

.. automodule:: nme
   :members:
   :show-inheritance:

   .. autodata:: REGISTER
   .. autodata:: MigrationInfo
   .. autofunction:: nme_object_encoder


Indices and tables
==================

* :ref:`genindex`
* :ref:`search`
